@@ -40,7 +40,7 @@
 #include <clutter/clutter.h>
 G_BEGIN_DECLS
 
-struct wl_input_device *clutter_wayland_input_device_get_wl_input_device (ClutterInputDevice *device);
+struct wl_seat *clutter_wayland_input_device_get_wl_seat (ClutterInputDevice *device);
 struct wl_shell_surface *clutter_wayland_stage_get_wl_shell_surface (ClutterStage *stage);
 struct wl_surface *clutter_wayland_stage_get_wl_surface (ClutterStage *stage);
 G_END_DECLS
