@@ -236,7 +236,7 @@ translate_key_event (ClutterBackendX11       *backend_x11,
   event->key.keyval =
     _clutter_keymap_x11_translate_key_state (backend_x11->keymap,
                                              event->key.hardware_keycode,
-                                             event->key.modifier_state,
+                                             &event->key.modifier_state,
                                              NULL);
 
   event_x11->key_group =
@@ -256,8 +256,8 @@ translate_key_event (ClutterBackendX11       *backend_x11,
   if (n != NoSymbol)
     {
       event->key.unicode_value = g_utf8_get_char_validated (buffer, n);
-      if ((event->key.unicode_value != -1) &&
-          (event->key.unicode_value != -2))
+      if ((event->key.unicode_value != (gunichar) -1) &&
+          (event->key.unicode_value != (gunichar) -2))
         goto out;
     }
   else
@@ -488,7 +488,7 @@ clutter_device_manager_x11_translate_event (ClutterEventTranslator *translator,
       event->crossing.related = NULL;
       clutter_event_set_device (event, manager_x11->core_pointer);
 
-      _clutter_stage_add_device (stage, manager_x11->core_pointer);
+      _clutter_input_device_set_stage (manager_x11->core_pointer, stage);
 
       res = CLUTTER_TRANSLATE_QUEUE;
       break;
@@ -514,7 +514,7 @@ clutter_device_manager_x11_translate_event (ClutterEventTranslator *translator,
       event->crossing.related = NULL;
       clutter_event_set_device (event, manager_x11->core_pointer);
 
-      _clutter_stage_remove_device (stage, manager_x11->core_pointer);
+      _clutter_input_device_set_stage (manager_x11->core_pointer, NULL);
 
       res = CLUTTER_TRANSLATE_QUEUE;
       break;
